import { z } from 'zod';
import { APIClient } from '@agentuity/api';
export declare const QueryColumnSchema: z.ZodObject<{
    name: z.ZodString;
    type: z.ZodString;
}, z.core.$strip>;
export declare const QueryResultSchema: z.ZodObject<{
    columns: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        type: z.ZodString;
    }, z.core.$strip>>;
    rows: z.ZodArray<z.ZodRecord<z.ZodString, z.ZodAny>>;
    rowCount: z.ZodNumber;
    truncated: z.ZodBoolean;
}, z.core.$strip>;
export declare const QueryResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    message: z.ZodOptional<z.ZodString>;
    data: z.ZodOptional<z.ZodObject<{
        columns: z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            type: z.ZodString;
        }, z.core.$strip>>;
        rows: z.ZodArray<z.ZodRecord<z.ZodString, z.ZodAny>>;
        rowCount: z.ZodNumber;
        truncated: z.ZodBoolean;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type QueryColumn = z.infer<typeof QueryColumnSchema>;
export type QueryResult = z.infer<typeof QueryResultSchema>;
declare const DbQueryRequestSchema: z.ZodObject<{
    database: z.ZodString;
    query: z.ZodString;
    orgId: z.ZodString;
    region: z.ZodString;
}, z.core.$strip>;
type DbQueryRequest = z.infer<typeof DbQueryRequestSchema>;
export declare function dbQuery(client: APIClient, request: DbQueryRequest): Promise<QueryResult>;
export {};
//# sourceMappingURL=query.d.ts.map